#ifndef LIBAWT_H
#define LIBAWT_H

#include "time.h"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <getopt.h>
#include <sys/types.h>
#include <pwd.h>
#include <stddef.h>
#include <wpa_ctrl.h>
#include <openssl/x509.h>
#include <dlfcn.h>
#include "rtpkcs11.h"

#define MAX_STRING_LEN 1024
#define MAXOBJLIST 128
#define CMDBUFSIZE 10240

#ifdef __cplusplus
extern "C" {
#endif

typedef enum {
    UNKNOWN_TOKEN_TYPE,
    ETOKEN_TOKEN_TYPE,
    JACARTA_TOKEN_TYPE,
    RUTOKEN_TOKEN_TYPE
} TokenType;

typedef struct {
    char name[MAX_STRING_LEN]; // Сертификат ЦС и т.п. значения
    char id[MAX_STRING_LEN]; // {555B3E1B-3549-4E13-8AD9-D77AA16C9343}
    char subject[MAX_STRING_LEN]; // /DC=ru/DC=warpnet/DC=vmdom/CN=vmdom-root-ca
    time_t start_date;
    time_t end_date;
} Certificate;

typedef struct {
    char path[MAX_STRING_LEN]; // путь до файла конфигурации
    TokenType token_type; // тип токена
    char CA_cert[MAX_STRING_LEN]; // путь до файла сертификата или Certificate::id
    char user_cert[MAX_STRING_LEN]; // сертификат пользователя
    char ssid[MAX_STRING_LEN]; // имя Wi-Fi сети
    char username[MAX_STRING_LEN]; // identity
    char pin[255]; // pin пользователя
} ConnectionConfig;

// token_type - тип токена
// certificates - вернуть из функции массив из структур Certificate
// size - вернуть из функции количество элементов в массиве
// error - вернуть из функции текст ошибки, если есть, если нет - NULL
int get_certificates_list(TokenType token_type, Certificate *certificates, int *size, char *error);

int save_config(ConnectionConfig *connection_config, char *error);

int connect_wifi(ConnectionConfig *connection_config, char *error);

int disconnect_wifi(char *error);

typedef enum {
	UNKNOWN_STATUS,
	DISCONNECTED_STATUS,
	INTERFACE_DISABLED_STATUS,
	INACTIVE_STATUS,
	SCANNING_STATUS,
	AUTHENTICATING_STATUS,
	ASSOCIATING_STATUS,
	ASSOCIATED_STATUS,
	FOURWAY_HANDSHAKE_STATUS,
	GROUP_HANDSHAKE_STATUS,
	COMPLETED_STATUS
} ConnectionStatus;

// текущий статус настроенного соединения
int get_current_status(ConnectionStatus *connection_status, char *error);

// timeout - время (в секундах) на сканирование доступных сетей
// ssids - возвращаемый из функции массив указателей на нуль-терминированные строки с именами доступных Wi-Fi сетей.
// size - вернуть из функции количество элементов в массиве
int get_ssids_list(int timeout, char **ssids, int *size, char *error);

#ifdef __cplusplus
}
#endif

#endif // LIBAWT_H/**
